@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import argparse
 import contextlib
 import functools
@@ -9,12 +11,8 @@ import time
 import unicodedata
 from typing import Any
 from typing import Collection
-from typing import Dict
-from typing import List
 from typing import MutableMapping
 from typing import Sequence
-from typing import Set
-from typing import Tuple
 
 from identify.identify import tags_from_path
 
@@ -62,7 +60,7 @@ def filter_by_include_exclude(
         names: Collection[str],
         include: str,
         exclude: str,
-) -> List[str]:
+) -> list[str]:
     include_re, exclude_re = re.compile(include), re.compile(exclude)
     return [
         filename for filename in names
@@ -76,7 +74,7 @@ class Classifier:
         self.filenames = [f for f in filenames if os.path.lexists(f)]
 
     @functools.lru_cache(maxsize=None)
-    def _types_for_file(self, filename: str) -> Set[str]:
+    def _types_for_file(self, filename: str) -> set[str]:
         return tags_from_path(filename)
 
     def by_types(
@@ -85,7 +83,7 @@ class Classifier:
             types: Collection[str],
             types_or: Collection[str],
             exclude_types: Collection[str],
-    ) -> List[str]:
+    ) -> list[str]:
         types = frozenset(types)
         types_or = frozenset(types_or)
         exclude_types = frozenset(exclude_types)
@@ -100,7 +98,7 @@ class Classifier:
                 ret.append(filename)
         return ret
 
-    def filenames_for_hook(self, hook: Hook) -> Tuple[str, ...]:
+    def filenames_for_hook(self, hook: Hook) -> tuple[str, ...]:
         names = self.filenames
         names = filter_by_include_exclude(names, hook.files, hook.exclude)
         names = self.by_types(
@@ -117,7 +115,7 @@ class Classifier:
             filenames: Collection[str],
             include: str,
             exclude: str,
-    ) -> 'Classifier':
+    ) -> Classifier:
         # on windows we normalize all filenames to use forward slashes
         # this makes it easier to filter using the `files:` regex
         # this also makes improperly quoted shell-based hooks work better
@@ -128,7 +126,7 @@ class Classifier:
         return Classifier(filenames)
 
 
-def _get_skips(environ: MutableMapping[str, str]) -> Set[str]:
+def _get_skips(environ: MutableMapping[str, str]) -> set[str]:
     skips = environ.get('SKIP', '')
     return {skip.strip() for skip in skips.split(',') if skip.strip()}
 
@@ -144,12 +142,12 @@ def _subtle_line(s: str, use_color: bool) -> None:
 def _run_single_hook(
         classifier: Classifier,
         hook: Hook,
-        skips: Set[str],
+        skips: set[str],
         cols: int,
         diff_before: bytes,
         verbose: bool,
         use_color: bool,
-) -> Tuple[bool, bytes]:
+) -> tuple[bool, bytes]:
     filenames = classifier.filenames_for_hook(hook)
 
     if hook.id in skips or hook.alias in skips:
@@ -191,7 +189,16 @@ def _run_single_hook(
             filenames = ()
         time_before = time.time()
         language = languages[hook.language]
-        retcode, out = language.run_hook(hook, filenames, use_color)
+        with language.in_env(hook.prefix, hook.language_version):
+            retcode, out = language.run_hook(
+                hook.prefix,
+                hook.entry,
+                hook.args,
+                filenames,
+                is_local=hook.src == 'local',
+                require_serial=hook.require_serial,
+                color=use_color,
+            )
         duration = round(time.time() - time_before, 2) or 0
         diff_after = _get_diff()
 
@@ -265,15 +272,16 @@ def _all_filenames(args: argparse.Namespace) -> Collection[str]:
 
 def _get_diff() -> bytes:
     _, out, _ = cmd_output_b(
-        'git', 'diff', '--no-ext-diff', '--ignore-submodules', retcode=None,
+        'git', 'diff', '--no-ext-diff', '--no-textconv', '--ignore-submodules',
+        check=False,
     )
     return out
 
 
 def _run_hooks(
-        config: Dict[str, Any],
+        config: dict[str, Any],
         hooks: Sequence[Hook],
-        skips: Set[str],
+        skips: set[str],
         args: argparse.Namespace,
 ) -> int:
     """Actually run the hooks."""
@@ -319,8 +327,7 @@ def _has_unmerged_paths() -> bool:
 
 def _has_unstaged_config(config_file: str) -> bool:
     retcode, _, _ = cmd_output_b(
-        'git', 'diff', '--no-ext-diff', '--exit-code', config_file,
-        retcode=None,
+        'git', 'diff', '--quiet', '--no-ext-diff', config_file, check=False,
     )
     # be explicit, other git errors don't mean it has an unstaged config.
     return retcode == 1
@@ -335,7 +342,7 @@ def run(
     stash = not args.all_files and not args.files
 
     # Check if we have unresolved merge conflict files and fail fast.
-    if _has_unmerged_paths():
+    if stash and _has_unmerged_paths():
         logger.error('Unmerged files.  Resolve before committing.')
         return 1
     if bool(args.from_ref) != bool(args.to_ref):
@@ -363,6 +370,16 @@ def run(
     ):
         return 0
 
+    # Expose prepare_commit_message_source / commit_object_name
+    # as environment variables for the hooks
+    if args.prepare_commit_message_source:
+        environ['PRE_COMMIT_COMMIT_MSG_SOURCE'] = (
+            args.prepare_commit_message_source
+        )
+
+    if args.commit_object_name:
+        environ['PRE_COMMIT_COMMIT_OBJECT_NAME'] = args.commit_object_name
+
     # Expose from-ref / to-ref as environment variables for hooks to consume
     if args.from_ref and args.to_ref:
         # legacy names
@@ -412,7 +429,11 @@ def run(
             return 1
 
         skips = _get_skips(environ)
-        to_install = [hook for hook in hooks if hook.id not in skips]
+        to_install = [
+            hook
+            for hook in hooks
+            if hook.id not in skips and hook.alias not in skips
+        ]
         install_hook_envs(to_install, store)
 
         return _run_hooks(config, hooks, skips, args)
