@@ -1,19 +1,14 @@
-import sys
+from __future__ import annotations
 
-if sys.version_info >= (3, 8):  # pragma: >=3.8 cover
-    import importlib.metadata as importlib_metadata
-else:  # pragma: <3.8 cover
-    import importlib_metadata
+import importlib.metadata
 
 CONFIG_FILE = '.pre-commit-config.yaml'
 MANIFEST_FILE = '.pre-commit-hooks.yaml'
 
-# Bump when installation changes in a backwards / forwards incompatible way
-INSTALLED_STATE_VERSION = '1'
 # Bump when modifying `empty_template`
 LOCAL_REPO_VERSION = '1'
 
-VERSION = importlib_metadata.version('pre_commit')
+VERSION = importlib.metadata.version('pre_commit')
 
 # `manual` is not invoked by any installed git hook.  See #719
 STAGES = (
@@ -22,4 +17,10 @@ STAGES = (
     'post-rewrite',
 )
 
+HOOK_TYPES = (
+    'pre-commit', 'pre-merge-commit', 'pre-push', 'prepare-commit-msg',
+    'commit-msg', 'post-commit', 'post-checkout', 'post-merge',
+    'post-rewrite',
+)
+
 DEFAULT = 'default'
