@@ -1,21 +1,20 @@
+from __future__ import annotations
+
 import hashlib
 import json
 import os
 from typing import Sequence
-from typing import Tuple
 
-import pre_commit.constants as C
-from pre_commit.hook import Hook
 from pre_commit.languages import helpers
 from pre_commit.prefix import Prefix
 from pre_commit.util import CalledProcessError
-from pre_commit.util import clean_path_on_failure
 from pre_commit.util import cmd_output_b
 
 ENVIRONMENT_DIR = 'docker'
 PRE_COMMIT_LABEL = 'PRE_COMMIT'
 get_default_version = helpers.basic_get_default_version
-healthy = helpers.basic_healthy
+health_check = helpers.basic_health_check
+in_env = helpers.no_env  # no special environment for docker
 
 
 def _is_in_docker() -> bool:
@@ -76,7 +75,7 @@ def build_docker_image(
         *,
         pull: bool,
 ) -> None:  # pragma: win32 no cover
-    cmd: Tuple[str, ...] = (
+    cmd: tuple[str, ...] = (
         'docker', 'build',
         '--tag', docker_tag(prefix),
         '--label', PRE_COMMIT_LABEL,
@@ -94,25 +93,22 @@ def install_environment(
     helpers.assert_version_default('docker', version)
     helpers.assert_no_additional_deps('docker', additional_dependencies)
 
-    directory = prefix.path(
-        helpers.environment_dir(ENVIRONMENT_DIR, C.DEFAULT),
-    )
+    directory = helpers.environment_dir(prefix, ENVIRONMENT_DIR, version)
 
     # Docker doesn't really have relevant disk environment, but pre-commit
     # still needs to cleanup its state files on failure
-    with clean_path_on_failure(directory):
-        build_docker_image(prefix, pull=True)
-        os.mkdir(directory)
+    build_docker_image(prefix, pull=True)
+    os.mkdir(directory)
 
 
-def get_docker_user() -> Tuple[str, ...]:  # pragma: win32 no cover
+def get_docker_user() -> tuple[str, ...]:  # pragma: win32 no cover
     try:
         return ('-u', f'{os.getuid()}:{os.getgid()}')
     except AttributeError:
         return ()
 
 
-def docker_cmd() -> Tuple[str, ...]:  # pragma: win32 no cover
+def docker_cmd() -> tuple[str, ...]:  # pragma: win32 no cover
     return (
         'docker', 'run',
         '--rm',
@@ -126,16 +122,26 @@ def docker_cmd() -> Tuple[str, ...]:  # pragma: win32 no cover
 
 
 def run_hook(
-        hook: Hook,
+        prefix: Prefix,
+        entry: str,
+        args: Sequence[str],
         file_args: Sequence[str],
+        *,
+        is_local: bool,
+        require_serial: bool,
         color: bool,
-) -> Tuple[int, bytes]:  # pragma: win32 no cover
+) -> tuple[int, bytes]:  # pragma: win32 no cover
     # Rebuild the docker image in case it has gone missing, as many people do
     # automated cleanup of docker images.
-    build_docker_image(hook.prefix, pull=False)
+    build_docker_image(prefix, pull=False)
 
-    entry_exe, *cmd_rest = hook.cmd
+    entry_exe, *cmd_rest = helpers.hook_cmd(entry, args)
 
-    entry_tag = ('--entrypoint', entry_exe, docker_tag(hook.prefix))
+    entry_tag = ('--entrypoint', entry_exe, docker_tag(prefix))
     cmd = (*docker_cmd(), *entry_tag, *cmd_rest)
-    return helpers.run_xargs(hook, cmd, file_args, color=color)
+    return helpers.run_xargs(
+        cmd,
+        file_args,
+        require_serial=require_serial,
+        color=color,
+    )
