@@ -1,25 +1,22 @@
+from __future__ import annotations
+
+import contextlib
 import multiprocessing
 import os
 import random
 import re
+import shlex
 from typing import Any
-from typing import List
-from typing import Optional
-from typing import overload
+from typing import Generator
+from typing import NoReturn
 from typing import Sequence
-from typing import Tuple
-from typing import TYPE_CHECKING
 
 import pre_commit.constants as C
 from pre_commit import parse_shebang
-from pre_commit.hook import Hook
 from pre_commit.prefix import Prefix
 from pre_commit.util import cmd_output_b
 from pre_commit.xargs import xargs
 
-if TYPE_CHECKING:
-    from typing import NoReturn
-
 FIXED_RANDOM_SEED = 1542676187
 
 SHIMS_RE = re.compile(r'[/\\]shims[/\\]')
@@ -32,7 +29,7 @@ def exe_exists(exe: str) -> bool:
 
     homedir = os.path.expanduser('~')
     try:
-        common: Optional[str] = os.path.commonpath((found, homedir))
+        common: str | None = os.path.commonpath((found, homedir))
     except ValueError:  # on windows, different drives raises ValueError
         common = None
 
@@ -48,27 +45,19 @@ def exe_exists(exe: str) -> bool:
     )
 
 
-def run_setup_cmd(prefix: Prefix, cmd: Tuple[str, ...], **kwargs: Any) -> None:
+def run_setup_cmd(prefix: Prefix, cmd: tuple[str, ...], **kwargs: Any) -> None:
     cmd_output_b(*cmd, cwd=prefix.prefix_dir, **kwargs)
 
 
-@overload
-def environment_dir(d: None, language_version: str) -> None: ...
-@overload
-def environment_dir(d: str, language_version: str) -> str: ...
-
-
-def environment_dir(d: Optional[str], language_version: str) -> Optional[str]:
-    if d is None:
-        return None
-    else:
-        return f'{d}-{language_version}'
+def environment_dir(prefix: Prefix, d: str, language_version: str) -> str:
+    return prefix.path(f'{d}-{language_version}')
 
 
 def assert_version_default(binary: str, version: str) -> None:
     if version != C.DEFAULT:
         raise AssertionError(
-            f'For now, pre-commit requires system-installed {binary}',
+            f'for now, pre-commit requires system-installed {binary} -- '
+            f'you selected `language_version: {version}`',
         )
 
 
@@ -78,8 +67,9 @@ def assert_no_additional_deps(
 ) -> None:
     if additional_deps:
         raise AssertionError(
-            f'For now, pre-commit does not support '
-            f'additional_dependencies for {lang}',
+            f'for now, pre-commit does not support '
+            f'additional_dependencies for {lang} -- '
+            f'you selected `additional_dependencies: {additional_deps}`',
         )
 
 
@@ -87,20 +77,25 @@ def basic_get_default_version() -> str:
     return C.DEFAULT
 
 
-def basic_healthy(prefix: Prefix, language_version: str) -> bool:
-    return True
+def basic_health_check(prefix: Prefix, language_version: str) -> str | None:
+    return None
 
 
 def no_install(
         prefix: Prefix,
         version: str,
         additional_dependencies: Sequence[str],
-) -> 'NoReturn':
-    raise AssertionError('This type is not installable')
+) -> NoReturn:
+    raise AssertionError('This language is not installable')
 
 
-def target_concurrency(hook: Hook) -> int:
-    if hook.require_serial or 'PRE_COMMIT_NO_CONCURRENCY' in os.environ:
+@contextlib.contextmanager
+def no_env(prefix: Prefix, version: str) -> Generator[None, None, None]:
+    yield
+
+
+def target_concurrency() -> int:
+    if 'PRE_COMMIT_NO_CONCURRENCY' in os.environ:
         return 1
     else:
         # Travis appears to have a bunch of CPUs, but we can't use them all.
@@ -113,7 +108,7 @@ def target_concurrency(hook: Hook) -> int:
                 return 1
 
 
-def _shuffled(seq: Sequence[str]) -> List[str]:
+def _shuffled(seq: Sequence[str]) -> list[str]:
     """Deterministically shuffle"""
     fixed_random = random.Random()
     fixed_random.seed(FIXED_RANDOM_SEED, version=1)
@@ -124,13 +119,40 @@ def _shuffled(seq: Sequence[str]) -> List[str]:
 
 
 def run_xargs(
-        hook: Hook,
-        cmd: Tuple[str, ...],
+        cmd: tuple[str, ...],
         file_args: Sequence[str],
-        **kwargs: Any,
-) -> Tuple[int, bytes]:
-    # Shuffle the files so that they more evenly fill out the xargs partitions,
-    # but do it deterministically in case a hook cares about ordering.
-    file_args = _shuffled(file_args)
-    kwargs['target_concurrency'] = target_concurrency(hook)
-    return xargs(cmd, file_args, **kwargs)
+        *,
+        require_serial: bool,
+        color: bool,
+) -> tuple[int, bytes]:
+    if require_serial:
+        jobs = 1
+    else:
+        # Shuffle the files so that they more evenly fill out the xargs
+        # partitions, but do it deterministically in case a hook cares about
+        # ordering.
+        file_args = _shuffled(file_args)
+        jobs = target_concurrency()
+    return xargs(cmd, file_args, target_concurrency=jobs, color=color)
+
+
+def hook_cmd(entry: str, args: Sequence[str]) -> tuple[str, ...]:
+    return (*shlex.split(entry), *args)
+
+
+def basic_run_hook(
+        prefix: Prefix,
+        entry: str,
+        args: Sequence[str],
+        file_args: Sequence[str],
+        *,
+        is_local: bool,
+        require_serial: bool,
+        color: bool,
+) -> tuple[int, bytes]:
+    return run_xargs(
+        hook_cmd(entry, args),
+        file_args,
+        require_serial=require_serial,
+        color=color,
+    )
