@@ -1,26 +1,21 @@
+from __future__ import annotations
+
 import contextlib
 import os
 import shlex
 from typing import Generator
 from typing import Sequence
-from typing import Tuple
 
 from pre_commit.envcontext import envcontext
 from pre_commit.envcontext import PatchesT
 from pre_commit.envcontext import Var
-from pre_commit.hook import Hook
 from pre_commit.languages import helpers
 from pre_commit.prefix import Prefix
-from pre_commit.util import clean_path_on_failure
 
 ENVIRONMENT_DIR = 'perl_env'
 get_default_version = helpers.basic_get_default_version
-healthy = helpers.basic_healthy
-
-
-def _envdir(prefix: Prefix, version: str) -> str:
-    directory = helpers.environment_dir(ENVIRONMENT_DIR, version)
-    return prefix.path(directory)
+health_check = helpers.basic_health_check
+run_hook = helpers.basic_run_hook
 
 
 def get_env_patch(venv: str) -> PatchesT:
@@ -38,11 +33,9 @@ def get_env_patch(venv: str) -> PatchesT:
 
 
 @contextlib.contextmanager
-def in_env(
-        prefix: Prefix,
-        language_version: str,
-) -> Generator[None, None, None]:
-    with envcontext(get_env_patch(_envdir(prefix, language_version))):
+def in_env(prefix: Prefix, version: str) -> Generator[None, None, None]:
+    envdir = helpers.environment_dir(prefix, ENVIRONMENT_DIR, version)
+    with envcontext(get_env_patch(envdir)):
         yield
 
 
@@ -51,17 +44,7 @@ def install_environment(
 ) -> None:
     helpers.assert_version_default('perl', version)
 
-    with clean_path_on_failure(_envdir(prefix, version)):
-        with in_env(prefix, version):
-            helpers.run_setup_cmd(
-                prefix, ('cpan', '-T', '.', *additional_dependencies),
-            )
-
-
-def run_hook(
-        hook: Hook,
-        file_args: Sequence[str],
-        color: bool,
-) -> Tuple[int, bytes]:
-    with in_env(hook.prefix, hook.language_version):
-        return helpers.run_xargs(hook, hook.cmd, file_args, color=color)
+    with in_env(prefix, version):
+        helpers.run_setup_cmd(
+            prefix, ('cpan', '-T', '.', *additional_dependencies),
+        )
