@@ -1,40 +1,42 @@
+from __future__ import annotations
+
 import json
 import logging
 import os
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
 from typing import Sequence
-from typing import Set
-from typing import Tuple
 
 import pre_commit.constants as C
 from pre_commit.clientlib import load_manifest
 from pre_commit.clientlib import LOCAL
 from pre_commit.clientlib import META
+from pre_commit.clientlib import parse_version
 from pre_commit.hook import Hook
 from pre_commit.languages.all import languages
 from pre_commit.languages.helpers import environment_dir
 from pre_commit.prefix import Prefix
 from pre_commit.store import Store
-from pre_commit.util import parse_version
+from pre_commit.util import clean_path_on_failure
 from pre_commit.util import rmtree
 
 
 logger = logging.getLogger('pre_commit')
 
 
+def _state_filename_v1(venv: str) -> str:
+    return os.path.join(venv, '.install_state_v1')
+
+
+def _state_filename_v2(venv: str) -> str:
+    return os.path.join(venv, '.install_state_v2')
+
+
 def _state(additional_deps: Sequence[str]) -> object:
     return {'additional_dependencies': sorted(additional_deps)}
 
 
-def _state_filename(prefix: Prefix, venv: str) -> str:
-    return prefix.path(venv, f'.install_state_v{C.INSTALLED_STATE_VERSION}')
-
-
-def _read_state(prefix: Prefix, venv: str) -> Optional[object]:
-    filename = _state_filename(prefix, venv)
+def _read_state(venv: str) -> object | None:
+    filename = _state_filename_v1(venv)
     if not os.path.exists(filename):
         return None
     else:
@@ -42,26 +44,22 @@ def _read_state(prefix: Prefix, venv: str) -> Optional[object]:
             return json.load(f)
 
 
-def _write_state(prefix: Prefix, venv: str, state: object) -> None:
-    state_filename = _state_filename(prefix, venv)
-    staging = f'{state_filename}staging'
-    with open(staging, 'w') as state_file:
-        state_file.write(json.dumps(state))
-    # Move the file into place atomically to indicate we've installed
-    os.replace(staging, state_filename)
-
-
 def _hook_installed(hook: Hook) -> bool:
     lang = languages[hook.language]
-    venv = environment_dir(lang.ENVIRONMENT_DIR, hook.language_version)
+    if lang.ENVIRONMENT_DIR is None:
+        return True
+
+    venv = environment_dir(
+        hook.prefix,
+        lang.ENVIRONMENT_DIR,
+        hook.language_version,
+    )
     return (
-        venv is None or (
-            (
-                _read_state(hook.prefix, venv) ==
-                _state(hook.additional_dependencies)
-            ) and
-            lang.healthy(hook.prefix, hook.language_version)
-        )
+        (
+            os.path.exists(_state_filename_v2(venv)) or
+            _read_state(venv) == _state(hook.additional_dependencies)
+        ) and
+        not lang.health_check(hook.prefix, hook.language_version)
     )
 
 
@@ -72,30 +70,47 @@ def _hook_install(hook: Hook) -> None:
 
     lang = languages[hook.language]
     assert lang.ENVIRONMENT_DIR is not None
-    venv = environment_dir(lang.ENVIRONMENT_DIR, hook.language_version)
+
+    venv = environment_dir(
+        hook.prefix,
+        lang.ENVIRONMENT_DIR,
+        hook.language_version,
+    )
 
     # There's potentially incomplete cleanup from previous runs
     # Clean it up!
-    if hook.prefix.exists(venv):
-        rmtree(hook.prefix.path(venv))
+    if os.path.exists(venv):
+        rmtree(venv)
 
-    lang.install_environment(
-        hook.prefix, hook.language_version, hook.additional_dependencies,
-    )
-    if not lang.healthy(hook.prefix, hook.language_version):
-        raise AssertionError(
-            f'BUG: expected environment for {hook.language} to be healthy() '
-            f'immediately after install, please open an issue describing '
-            f'your environment',
+    with clean_path_on_failure(venv):
+        lang.install_environment(
+            hook.prefix, hook.language_version, hook.additional_dependencies,
         )
-    # Write our state to indicate we're installed
-    _write_state(hook.prefix, venv, _state(hook.additional_dependencies))
+        health_error = lang.health_check(hook.prefix, hook.language_version)
+        if health_error:
+            raise AssertionError(
+                f'BUG: expected environment for {hook.language} to be healthy '
+                f'immediately after install, please open an issue describing '
+                f'your environment\n\n'
+                f'more info:\n\n{health_error}',
+            )
+
+        # TODO: remove v1 state writing, no longer needed after pre-commit 3.0
+        # Write our state to indicate we're installed
+        state_filename = _state_filename_v1(venv)
+        staging = f'{state_filename}staging'
+        with open(staging, 'w') as state_file:
+            state_file.write(json.dumps(_state(hook.additional_dependencies)))
+        # Move the file into place atomically to indicate we've installed
+        os.replace(staging, state_filename)
+
+        open(_state_filename_v2(venv), 'a+').close()
 
 
 def _hook(
-        *hook_dicts: Dict[str, Any],
-        root_config: Dict[str, Any],
-) -> Dict[str, Any]:
+        *hook_dicts: dict[str, Any],
+        root_config: dict[str, Any],
+) -> dict[str, Any]:
     ret, rest = dict(hook_dicts[0]), hook_dicts[1:]
     for dct in rest:
         ret.update(dct)
@@ -140,10 +155,10 @@ def _hook(
 
 
 def _non_cloned_repository_hooks(
-        repo_config: Dict[str, Any],
+        repo_config: dict[str, Any],
         store: Store,
-        root_config: Dict[str, Any],
-) -> Tuple[Hook, ...]:
+        root_config: dict[str, Any],
+) -> tuple[Hook, ...]:
     def _prefix(language_name: str, deps: Sequence[str]) -> Prefix:
         language = languages[language_name]
         # pygrep / script / system / docker_image do not have
@@ -164,10 +179,10 @@ def _non_cloned_repository_hooks(
 
 
 def _cloned_repository_hooks(
-        repo_config: Dict[str, Any],
+        repo_config: dict[str, Any],
         store: Store,
-        root_config: Dict[str, Any],
-) -> Tuple[Hook, ...]:
+        root_config: dict[str, Any],
+) -> tuple[Hook, ...]:
     repo, rev = repo_config['repo'], repo_config['rev']
     manifest_path = os.path.join(store.clone(repo, rev), C.MANIFEST_FILE)
     by_id = {hook['id']: hook for hook in load_manifest(manifest_path)}
@@ -196,10 +211,10 @@ def _cloned_repository_hooks(
 
 
 def _repository_hooks(
-        repo_config: Dict[str, Any],
+        repo_config: dict[str, Any],
         store: Store,
-        root_config: Dict[str, Any],
-) -> Tuple[Hook, ...]:
+        root_config: dict[str, Any],
+) -> tuple[Hook, ...]:
     if repo_config['repo'] in {LOCAL, META}:
         return _non_cloned_repository_hooks(repo_config, store, root_config)
     else:
@@ -207,8 +222,8 @@ def _repository_hooks(
 
 
 def install_hook_envs(hooks: Sequence[Hook], store: Store) -> None:
-    def _need_installed() -> List[Hook]:
-        seen: Set[Tuple[Prefix, str, str, Tuple[str, ...]]] = set()
+    def _need_installed() -> list[Hook]:
+        seen: set[tuple[Prefix, str, str, tuple[str, ...]]] = set()
         ret = []
         for hook in hooks:
             if hook.install_key not in seen and not _hook_installed(hook):
@@ -224,7 +239,7 @@ def install_hook_envs(hooks: Sequence[Hook], store: Store) -> None:
             _hook_install(hook)
 
 
-def all_hooks(root_config: Dict[str, Any], store: Store) -> Tuple[Hook, ...]:
+def all_hooks(root_config: dict[str, Any], store: Store) -> tuple[Hook, ...]:
     return tuple(
         hook
         for repo in root_config['repos']
