@@ -1,45 +1,21 @@
+from __future__ import annotations
+
 import contextlib
 import errno
-import functools
+import importlib.resources
 import os.path
 import shutil
 import stat
 import subprocess
 import sys
-import tempfile
 from types import TracebackType
 from typing import Any
 from typing import Callable
-from typing import Dict
 from typing import Generator
 from typing import IO
-from typing import Optional
-from typing import Tuple
-from typing import Type
-
-import yaml
 
 from pre_commit import parse_shebang
 
-if sys.version_info >= (3, 7):  # pragma: >=3.7 cover
-    from importlib.resources import open_binary
-    from importlib.resources import read_text
-else:  # pragma: <3.7 cover
-    from importlib_resources import open_binary
-    from importlib_resources import read_text
-
-Loader = getattr(yaml, 'CSafeLoader', yaml.SafeLoader)
-yaml_load = functools.partial(yaml.load, Loader=Loader)
-Dumper = getattr(yaml, 'CSafeDumper', yaml.SafeDumper)
-
-
-def yaml_dump(o: Any, **kwargs: Any) -> str:
-    # when python/mypy#1484 is solved, this can be `functools.partial`
-    return yaml.dump(
-        o, Dumper=Dumper, default_flow_style=False, indent=4, sort_keys=False,
-        **kwargs,
-    )
-
 
 def force_bytes(exc: Any) -> bytes:
     with contextlib.suppress(TypeError):
@@ -60,24 +36,12 @@ def clean_path_on_failure(path: str) -> Generator[None, None, None]:
         raise
 
 
-@contextlib.contextmanager
-def tmpdir() -> Generator[str, None, None]:
-    """Contextmanager to create a temporary directory.  It will be cleaned up
-    afterwards.
-    """
-    tempdir = tempfile.mkdtemp()
-    try:
-        yield tempdir
-    finally:
-        rmtree(tempdir)
-
-
 def resource_bytesio(filename: str) -> IO[bytes]:
-    return open_binary('pre_commit.resources', filename)
+    return importlib.resources.open_binary('pre_commit.resources', filename)
 
 
 def resource_text(filename: str) -> str:
-    return read_text('pre_commit.resources', filename)
+    return importlib.resources.read_text('pre_commit.resources', filename)
 
 
 def make_executable(filename: str) -> None:
@@ -90,20 +54,18 @@ class CalledProcessError(RuntimeError):
     def __init__(
             self,
             returncode: int,
-            cmd: Tuple[str, ...],
-            expected_returncode: int,
+            cmd: tuple[str, ...],
             stdout: bytes,
-            stderr: Optional[bytes],
+            stderr: bytes | None,
     ) -> None:
-        super().__init__(returncode, cmd, expected_returncode, stdout, stderr)
+        super().__init__(returncode, cmd, stdout, stderr)
         self.returncode = returncode
         self.cmd = cmd
-        self.expected_returncode = expected_returncode
         self.stdout = stdout
         self.stderr = stderr
 
     def __bytes__(self) -> bytes:
-        def _indent_or_none(part: Optional[bytes]) -> bytes:
+        def _indent_or_none(part: bytes | None) -> bytes:
             if part:
                 return b'\n    ' + part.replace(b'\n', b'\n    ')
             else:
@@ -112,7 +74,6 @@ class CalledProcessError(RuntimeError):
         return b''.join((
             f'command: {self.cmd!r}\n'.encode(),
             f'return code: {self.returncode}\n'.encode(),
-            f'expected return code: {self.expected_returncode}\n'.encode(),
             b'stdout:', _indent_or_none(self.stdout), b'\n',
             b'stderr:', _indent_or_none(self.stderr),
         ))
@@ -121,24 +82,24 @@ class CalledProcessError(RuntimeError):
         return self.__bytes__().decode()
 
 
-def _setdefault_kwargs(kwargs: Dict[str, Any]) -> None:
+def _setdefault_kwargs(kwargs: dict[str, Any]) -> None:
     for arg in ('stdin', 'stdout', 'stderr'):
         kwargs.setdefault(arg, subprocess.PIPE)
 
 
-def _oserror_to_output(e: OSError) -> Tuple[int, bytes, None]:
+def _oserror_to_output(e: OSError) -> tuple[int, bytes, None]:
     return 1, force_bytes(e).rstrip(b'\n') + b'\n', None
 
 
 def cmd_output_b(
         *cmd: str,
-        retcode: Optional[int] = 0,
+        check: bool = True,
         **kwargs: Any,
-) -> Tuple[int, bytes, Optional[bytes]]:
+) -> tuple[int, bytes, bytes | None]:
     _setdefault_kwargs(kwargs)
 
     try:
-        cmd = parse_shebang.normalize_cmd(cmd)
+        cmd = parse_shebang.normalize_cmd(cmd, env=kwargs.get('env'))
     except parse_shebang.ExecutableNotFoundError as e:
         returncode, stdout_b, stderr_b = e.to_output()
     else:
@@ -150,13 +111,13 @@ def cmd_output_b(
             stdout_b, stderr_b = proc.communicate()
             returncode = proc.returncode
 
-    if retcode is not None and retcode != returncode:
-        raise CalledProcessError(returncode, cmd, retcode, stdout_b, stderr_b)
+    if check and returncode:
+        raise CalledProcessError(returncode, cmd, stdout_b, stderr_b)
 
     return returncode, stdout_b, stderr_b
 
 
-def cmd_output(*cmd: str, **kwargs: Any) -> Tuple[int, str, Optional[str]]:
+def cmd_output(*cmd: str, **kwargs: Any) -> tuple[int, str, str | None]:
     returncode, stdout_b, stderr_b = cmd_output_b(*cmd, **kwargs)
     stdout = stdout_b.decode() if stdout_b is not None else None
     stderr = stderr_b.decode() if stderr_b is not None else None
@@ -169,17 +130,17 @@ if os.name != 'nt':  # pragma: win32 no cover
 
     class Pty:
         def __init__(self) -> None:
-            self.r: Optional[int] = None
-            self.w: Optional[int] = None
+            self.r: int | None = None
+            self.w: int | None = None
 
-        def __enter__(self) -> 'Pty':
+        def __enter__(self) -> Pty:
             self.r, self.w = openpty()
 
             # tty flags normally change \n to \r\n
-            attrs = termios.tcgetattr(self.r)
+            attrs = termios.tcgetattr(self.w)
             assert isinstance(attrs[1], int)
             attrs[1] &= ~(termios.ONLCR | termios.OPOST)
-            termios.tcsetattr(self.r, termios.TCSANOW, attrs)
+            termios.tcsetattr(self.w, termios.TCSANOW, attrs)
 
             return self
 
@@ -195,19 +156,19 @@ if os.name != 'nt':  # pragma: win32 no cover
 
         def __exit__(
                 self,
-                exc_type: Optional[Type[BaseException]],
-                exc_value: Optional[BaseException],
-                traceback: Optional[TracebackType],
+                exc_type: type[BaseException] | None,
+                exc_value: BaseException | None,
+                traceback: TracebackType | None,
         ) -> None:
             self.close_w()
             self.close_r()
 
     def cmd_output_p(
             *cmd: str,
-            retcode: Optional[int] = 0,
+            check: bool = True,
             **kwargs: Any,
-    ) -> Tuple[int, bytes, Optional[bytes]]:
-        assert retcode is None
+    ) -> tuple[int, bytes, bytes | None]:
+        assert check is False
         assert kwargs['stderr'] == subprocess.STDOUT, kwargs['stderr']
         _setdefault_kwargs(kwargs)
 
@@ -250,7 +211,7 @@ def rmtree(path: str) -> None:
     def handle_remove_readonly(
             func: Callable[..., Any],
             path: str,
-            exc: Tuple[Type[OSError], OSError, TracebackType],
+            exc: tuple[type[OSError], OSError, TracebackType],
     ) -> None:
         excvalue = exc[1]
         if (
@@ -265,10 +226,5 @@ def rmtree(path: str) -> None:
     shutil.rmtree(path, ignore_errors=False, onerror=handle_remove_readonly)
 
 
-def parse_version(s: str) -> Tuple[int, ...]:
-    """poor man's version comparison"""
-    return tuple(int(p) for p in s.split('.'))
-
-
 def win_exe(s: str) -> str:
     return s if sys.platform != 'win32' else f'{s}.exe'
