@@ -17,12 +17,10 @@ from pre_commit.envcontext import envcontext
 from pre_commit.hook import Hook
 from pre_commit.languages import golang
 from pre_commit.languages import helpers
-from pre_commit.languages import node
 from pre_commit.languages import python
-from pre_commit.languages import ruby
-from pre_commit.languages import rust
 from pre_commit.languages.all import languages
 from pre_commit.prefix import Prefix
+from pre_commit.repository import _hook_installed
 from pre_commit.repository import all_hooks
 from pre_commit.repository import install_hook_envs
 from pre_commit.util import cmd_output
@@ -32,11 +30,7 @@ from testing.fixtures import make_repo
 from testing.fixtures import modify_manifest
 from testing.util import cwd
 from testing.util import get_resource_path
-from testing.util import skipif_cant_run_coursier
 from testing.util import skipif_cant_run_docker
-from testing.util import skipif_cant_run_lua
-from testing.util import skipif_cant_run_swift
-from testing.util import xfailif_windows
 
 
 def _norm_out(b):
@@ -44,7 +38,16 @@ def _norm_out(b):
 
 
 def _hook_run(hook, filenames, color):
-    return languages[hook.language].run_hook(hook, filenames, color)
+    with languages[hook.language].in_env(hook.prefix, hook.language_version):
+        return languages[hook.language].run_hook(
+            hook.prefix,
+            hook.entry,
+            hook.args,
+            filenames,
+            is_local=hook.src == 'local',
+            require_serial=hook.require_serial,
+            color=color,
+        )
 
 
 def _get_hook_no_install(repo_config, store, hook_id):
@@ -81,47 +84,6 @@ def _test_hook_repo(
     assert _norm_out(out) == expected
 
 
-def test_conda_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'conda_hooks_repo',
-        'sys-exec', [os.devnull],
-        b'conda-default\n',
-    )
-
-
-def test_conda_with_additional_dependencies_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'conda_hooks_repo',
-        'additional-deps', [os.devnull],
-        b'OK\n',
-        config_kwargs={
-            'hooks': [{
-                'id': 'additional-deps',
-                'args': ['-c', 'import tzdata; print("OK")'],
-                'additional_dependencies': ['python-tzdata'],
-            }],
-        },
-    )
-
-
-def test_local_conda_additional_dependencies(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'local-conda',
-            'name': 'local-conda',
-            'entry': 'python',
-            'language': 'conda',
-            'args': ['-c', 'import botocore; print("OK")'],
-            'additional_dependencies': ['botocore'],
-        }],
-    }
-    hook = _get_hook(config, store, 'local-conda')
-    ret, out = _hook_run(hook, (), color=False)
-    assert ret == 0
-    assert _norm_out(out) == b'OK\n'
-
-
 def test_python_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'python_hooks_repo',
@@ -133,9 +95,11 @@ def test_python_hook(tempdir_factory, store):
 def test_python_hook_default_version(tempdir_factory, store):
     # make sure that this continues to work for platforms where default
     # language detection does not work
-    returns_default = mock.Mock(return_value=C.DEFAULT)
-    lang = languages['python']._replace(get_default_version=returns_default)
-    with mock.patch.dict(languages, python=lang):
+    with mock.patch.object(
+            python,
+            'get_default_version',
+            return_value=C.DEFAULT,
+    ):
         test_python_hook(tempdir_factory, store)
 
 
@@ -173,39 +137,20 @@ def test_python_venv(tempdir_factory, store):
     )
 
 
-@xfailif_windows  # pragma: win32 no cover  # no python 2 in GHA
-def test_switch_language_versions_doesnt_clobber(tempdir_factory, store):
-    # We're using the python3 repo because it prints the python version
-    path = make_repo(tempdir_factory, 'python3_hooks_repo')
-
-    def run_on_version(version, expected_output):
-        config = make_config_from_repo(path)
-        config['hooks'][0]['language_version'] = version
-        hook = _get_hook(config, store, 'python3-hook')
-        ret, out = _hook_run(hook, [], color=False)
-        assert ret == 0
-        assert _norm_out(out) == expected_output
-
-    run_on_version('python2', b'2\n[]\nHello World\n')
-    run_on_version('python3', b'3\n[]\nHello World\n')
-
-
-def test_versioned_python_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'python3_hooks_repo',
-        'python3-hook',
-        [os.devnull],
-        f'3\n[{os.devnull!r}]\nHello World\n'.encode(),
-    )
-
-
-@skipif_cant_run_coursier  # pragma: win32 no cover
-def test_run_a_coursier_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'coursier_hooks_repo',
-        'echo-java',
-        ['Hello World from coursier'], b'Hello World from coursier\n',
-    )
+def test_language_versioned_python_hook(tempdir_factory, store):
+    # we patch this force virtualenv executing with `-p` since we can't
+    # reliably have multiple pythons available in CI
+    with mock.patch.object(
+            python,
+            '_sys_executable_matches',
+            return_value=False,
+    ):
+        _test_hook_repo(
+            tempdir_factory, store, 'python3_hooks_repo',
+            'python3-hook',
+            [os.devnull],
+            f'3\n[{os.devnull!r}]\nHello World\n'.encode(),
+        )
 
 
 @skipif_cant_run_docker  # pragma: win32 no cover
@@ -247,130 +192,6 @@ def test_run_a_docker_image_hook(tempdir_factory, store, hook_id):
     )
 
 
-def test_run_a_node_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'node_hooks_repo',
-        'foo', [os.devnull], b'Hello World\n',
-    )
-
-
-def test_run_a_node_hook_default_version(tempdir_factory, store):
-    # make sure that this continues to work for platforms where node is not
-    # installed at the system
-    returns_default = mock.Mock(return_value=C.DEFAULT)
-    lang = languages['node']._replace(get_default_version=returns_default)
-    with mock.patch.dict(languages, node=lang):
-        test_run_a_node_hook(tempdir_factory, store)
-
-
-def test_run_versioned_node_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'node_versioned_hooks_repo',
-        'versioned-node-hook', [os.devnull], b'v9.3.0\nHello World\n',
-    )
-
-
-def test_node_hook_with_npm_userconfig_set(tempdir_factory, store, tmpdir):
-    cfg = tmpdir.join('cfg')
-    cfg.write('cache=/dne\n')
-    with mock.patch.dict(os.environ, NPM_CONFIG_USERCONFIG=str(cfg)):
-        test_run_a_node_hook(tempdir_factory, store)
-
-
-def test_r_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'r_hooks_repo',
-        'hello-world', [os.devnull],
-        b'Hello, World, from R!\n',
-    )
-
-
-def test_r_inline_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'r_hooks_repo',
-        'hello-world-inline', ['some-file'],
-        b'Hi-there, some-file, from R!\n',
-    )
-
-
-def test_r_with_additional_dependencies_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'r_hooks_repo',
-        'additional-deps', [os.devnull],
-        b'OK\n',
-        config_kwargs={
-            'hooks': [{
-                'id': 'additional-deps',
-                'additional_dependencies': ['cachem@1.0.4'],
-            }],
-        },
-    )
-
-
-def test_r_local_with_additional_dependencies_hook(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'local-r',
-            'name': 'local-r',
-            'entry': 'Rscript -e',
-            'language': 'r',
-            'args': ['if (packageVersion("R6") == "2.1.3") cat("OK\n")'],
-            'additional_dependencies': ['R6@2.1.3'],
-        }],
-    }
-    hook = _get_hook(config, store, 'local-r')
-    ret, out = _hook_run(hook, (), color=False)
-    assert ret == 0
-    assert _norm_out(out) == b'OK\n'
-
-
-def test_run_a_ruby_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'ruby_hooks_repo',
-        'ruby_hook', [os.devnull], b'Hello world from a ruby hook\n',
-    )
-
-
-def test_run_a_ruby_hook_with_user_install_set(tempdir_factory, store, tmpdir):
-    gemrc = tmpdir.join('gemrc')
-    gemrc.write('gem: --user-install\n')
-    with envcontext((('GEMRC', str(gemrc)),)):
-        test_run_a_ruby_hook(tempdir_factory, store)
-
-
-@xfailif_windows  # pragma: win32 no cover
-def test_run_versioned_ruby_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'ruby_versioned_hooks_repo',
-        'ruby_hook',
-        [os.devnull],
-        b'2.5.1\nHello world from a ruby hook\n',
-    )
-
-
-@xfailif_windows  # pragma: win32 no cover
-def test_run_ruby_hook_with_disable_shared_gems(
-        tempdir_factory,
-        store,
-        tmpdir,
-):
-    """Make sure a Gemfile in the project doesn't interfere."""
-    tmpdir.join('Gemfile').write('gem "lol_hai"')
-    tmpdir.join('.bundle').mkdir()
-    tmpdir.join('.bundle', 'config').write(
-        'BUNDLE_DISABLE_SHARED_GEMS: true\n'
-        'BUNDLE_PATH: vendor/gem\n',
-    )
-    with cwd(tmpdir.strpath):
-        _test_hook_repo(
-            tempdir_factory, store, 'ruby_versioned_hooks_repo',
-            'ruby_hook',
-            [os.devnull],
-            b'2.5.1\nHello world from a ruby hook\n',
-        )
-
-
 def test_system_hook_with_spaces(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'system_hook_with_spaces_repo',
@@ -378,25 +199,36 @@ def test_system_hook_with_spaces(tempdir_factory, store):
     )
 
 
-@skipif_cant_run_swift  # pragma: win32 no cover
-def test_swift_hook(tempdir_factory, store):
+def test_golang_system_hook(tempdir_factory, store):
     _test_hook_repo(
-        tempdir_factory, store, 'swift_hooks_repo',
-        'swift-hooks-repo', [], b'Hello, world!\n',
+        tempdir_factory, store, 'golang_hooks_repo',
+        'golang-hook', ['system'], b'hello world from system\n',
+        config_kwargs={
+            'hooks': [{
+                'id': 'golang-hook',
+                'language_version': 'system',
+            }],
+        },
     )
 
 
-def test_golang_hook(tempdir_factory, store):
+def test_golang_versioned_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'golang_hooks_repo',
-        'golang-hook', [], b'hello world\n',
+        'golang-hook', [], b'hello world from go1.18.4\n',
+        config_kwargs={
+            'hooks': [{
+                'id': 'golang-hook',
+                'language_version': '1.18.4',
+            }],
+        },
     )
 
 
 def test_golang_hook_still_works_when_gobin_is_set(tempdir_factory, store):
     gobin_dir = tempdir_factory.get()
     with envcontext((('GOBIN', gobin_dir),)):
-        test_golang_hook(tempdir_factory, store)
+        test_golang_system_hook(tempdir_factory, store)
     assert os.listdir(gobin_dir) == []
 
 
@@ -453,52 +285,6 @@ func main() {
     assert _norm_out(out) == b'hello hello world\n'
 
 
-def test_rust_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'rust_hooks_repo',
-        'rust-hook', [], b'hello world\n',
-    )
-
-
-@pytest.mark.parametrize('dep', ('cli:shellharden:3.1.0', 'cli:shellharden'))
-def test_additional_rust_cli_dependencies_installed(
-        tempdir_factory, store, dep,
-):
-    path = make_repo(tempdir_factory, 'rust_hooks_repo')
-    config = make_config_from_repo(path)
-    # A small rust package with no dependencies.
-    config['hooks'][0]['additional_dependencies'] = [dep]
-    hook = _get_hook(config, store, 'rust-hook')
-    binaries = os.listdir(
-        hook.prefix.path(
-            helpers.environment_dir(rust.ENVIRONMENT_DIR, C.DEFAULT), 'bin',
-        ),
-    )
-    # normalize for windows
-    binaries = [os.path.splitext(binary)[0] for binary in binaries]
-    assert 'shellharden' in binaries
-
-
-def test_additional_rust_lib_dependencies_installed(
-        tempdir_factory, store,
-):
-    path = make_repo(tempdir_factory, 'rust_hooks_repo')
-    config = make_config_from_repo(path)
-    # A small rust package with no dependencies.
-    deps = ['shellharden:3.1.0']
-    config['hooks'][0]['additional_dependencies'] = deps
-    hook = _get_hook(config, store, 'rust-hook')
-    binaries = os.listdir(
-        hook.prefix.path(
-            helpers.environment_dir(rust.ENVIRONMENT_DIR, C.DEFAULT), 'bin',
-        ),
-    )
-    # normalize for windows
-    binaries = [os.path.splitext(binary)[0] for binary in binaries]
-    assert 'rust-hello-world' in binaries
-    assert 'shellharden' not in binaries
-
-
 def test_missing_executable(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'not_found_exe',
@@ -648,25 +434,19 @@ def test_additional_dependencies_roll_forward(tempdir_factory, store):
         assert 'mccabe' not in cmd_output('pip', 'freeze', '-l')[1]
 
 
-def test_additional_ruby_dependencies_installed(tempdir_factory, store):
-    path = make_repo(tempdir_factory, 'ruby_hooks_repo')
-    config = make_config_from_repo(path)
-    config['hooks'][0]['additional_dependencies'] = ['tins']
-    hook = _get_hook(config, store, 'ruby_hook')
-    with ruby.in_env(hook.prefix, hook.language_version):
-        output = cmd_output('gem', 'list', '--local')[1]
-        assert 'tins' in output
+@pytest.mark.parametrize('v', ('v1', 'v2'))
+def test_repository_state_compatibility(tempdir_factory, store, v):
+    path = make_repo(tempdir_factory, 'python_hooks_repo')
 
-
-def test_additional_node_dependencies_installed(tempdir_factory, store):
-    path = make_repo(tempdir_factory, 'node_hooks_repo')
     config = make_config_from_repo(path)
-    # Careful to choose a small package that's not depped by npm
-    config['hooks'][0]['additional_dependencies'] = ['lodash']
     hook = _get_hook(config, store, 'foo')
-    with node.in_env(hook.prefix, hook.language_version):
-        output = cmd_output('npm', 'ls', '-g')[1]
-        assert 'lodash' in output
+    envdir = helpers.environment_dir(
+        hook.prefix,
+        python.ENVIRONMENT_DIR,
+        hook.language_version,
+    )
+    os.remove(os.path.join(envdir, f'.install_state_{v}'))
+    assert _hook_installed(hook) is True
 
 
 def test_additional_golang_dependencies_installed(
@@ -678,11 +458,12 @@ def test_additional_golang_dependencies_installed(
     deps = ['golang.org/x/example/hello@latest']
     config['hooks'][0]['additional_dependencies'] = deps
     hook = _get_hook(config, store, 'golang-hook')
-    binaries = os.listdir(
-        hook.prefix.path(
-            helpers.environment_dir(golang.ENVIRONMENT_DIR, C.DEFAULT), 'bin',
-        ),
+    envdir = helpers.environment_dir(
+        hook.prefix,
+        golang.ENVIRONMENT_DIR,
+        golang.get_default_version(),
     )
+    binaries = os.listdir(os.path.join(envdir, 'bin'))
     # normalize for windows
     binaries = [os.path.splitext(binary)[0] for binary in binaries]
     assert 'hello' in binaries
@@ -705,23 +486,6 @@ def test_local_golang_additional_dependencies(store):
     assert _norm_out(out) == b'Hello, Go examples!\n'
 
 
-def test_local_rust_additional_dependencies(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'hello',
-            'name': 'hello',
-            'entry': 'hello',
-            'language': 'rust',
-            'additional_dependencies': ['cli:hello-cli:0.2.2'],
-        }],
-    }
-    hook = _get_hook(config, store, 'hello')
-    ret, out = _hook_run(hook, (), color=False)
-    assert ret == 0
-    assert _norm_out(out) == b'Hello World!\n'
-
-
 def test_fail_hooks(store):
     config = {
         'repo': 'local',
@@ -798,10 +562,14 @@ def test_control_c_control_c_on_install(tempdir_factory, store):
 
     # Should have made an environment, however this environment is broken!
     hook, = hooks
-    assert hook.prefix.exists(
-        helpers.environment_dir(python.ENVIRONMENT_DIR, hook.language_version),
+    envdir = helpers.environment_dir(
+        hook.prefix,
+        python.ENVIRONMENT_DIR,
+        hook.language_version,
     )
 
+    assert os.path.exists(envdir)
+
     # However, it should be perfectly runnable (reinstall after botched
     # install)
     install_hook_envs(hooks, store)
@@ -817,10 +585,12 @@ def test_invalidated_virtualenv(tempdir_factory, store):
     hook = _get_hook(config, store, 'foo')
 
     # Simulate breaking of the virtualenv
-    libdir = hook.prefix.path(
-        helpers.environment_dir(python.ENVIRONMENT_DIR, hook.language_version),
-        'lib', hook.language_version,
+    envdir = helpers.environment_dir(
+        hook.prefix,
+        python.ENVIRONMENT_DIR,
+        hook.language_version,
     )
+    libdir = os.path.join(envdir, 'lib', hook.language_version)
     paths = [
         os.path.join(libdir, p) for p in ('site.py', 'site.pyc', '__pycache__')
     ]
@@ -883,7 +653,7 @@ def test_tags_on_repositories(in_tmpdir, tempdir_factory, store):
 @pytest.fixture
 def local_python_config():
     # Make a "local" hooks repo that just installs our other hooks repo
-    repo_path = get_resource_path('python3_hooks_repo')
+    repo_path = get_resource_path('python_hooks_repo')
     manifest = load_manifest(os.path.join(repo_path, C.MANIFEST_FILE))
     hooks = [
         dict(hook, additional_dependencies=[repo_path]) for hook in manifest
@@ -892,23 +662,12 @@ def local_python_config():
 
 
 def test_local_python_repo(store, local_python_config):
-    hook = _get_hook(local_python_config, store, 'python3-hook')
+    hook = _get_hook(local_python_config, store, 'foo')
     # language_version should have been adjusted to the interpreter version
     assert hook.language_version != C.DEFAULT
     ret, out = _hook_run(hook, ('filename',), color=False)
     assert ret == 0
-    assert _norm_out(out) == b"3\n['filename']\nHello World\n"
-
-
-@xfailif_windows  # pragma: win32 no cover  # no python2 in GHA
-def test_local_python_repo_python2(store, local_python_config):
-    local_python_config['hooks'][0]['language_version'] = 'python2'
-    hook = _get_hook(local_python_config, store, 'python3-hook')
-    # language_version should have been adjusted to the interpreter version
-    assert hook.language_version != C.DEFAULT
-    ret, out = _hook_run(hook, ('filename',), color=False)
-    assert ret == 0
-    assert _norm_out(out) == b"2\n['filename']\nHello World\n"
+    assert _norm_out(out) == b"['filename']\nHello World\n"
 
 
 def test_default_language_version(store, local_python_config):
@@ -1022,36 +781,13 @@ def test_manifest_hooks(tempdir_factory, store):
     )
 
 
-def test_perl_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'perl_hooks_repo',
-        'perl-hook', [], b'Hello from perl-commit Perl!\n',
-    )
-
-
-def test_local_perl_additional_dependencies(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'hello',
-            'name': 'hello',
-            'entry': 'perltidy --version',
-            'language': 'perl',
-            'additional_dependencies': ['SHANCOCK/Perl-Tidy-20211029.tar.gz'],
-        }],
-    }
-    hook = _get_hook(config, store, 'hello')
-    ret, out = _hook_run(hook, (), color=False)
-    assert ret == 0
-    assert _norm_out(out).startswith(b'This is perltidy, v20211029')
-
-
 @pytest.mark.parametrize(
     'repo',
     (
         'dotnet_hooks_csproj_repo',
         'dotnet_hooks_sln_repo',
         'dotnet_hooks_combo_repo',
+        'dotnet_hooks_csproj_prefix_repo',
     ),
 )
 def test_dotnet_hook(tempdir_factory, store, repo):
@@ -1061,46 +797,6 @@ def test_dotnet_hook(tempdir_factory, store, repo):
     )
 
 
-def test_dart_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'dart_repo',
-        'hello-world-dart', [], b'hello hello world\n',
-    )
-
-
-def test_local_dart_additional_dependencies(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'local-dart',
-            'name': 'local-dart',
-            'entry': 'hello-world-dart',
-            'language': 'dart',
-            'additional_dependencies': ['hello_world_dart'],
-        }],
-    }
-    hook = _get_hook(config, store, 'local-dart')
-    ret, out = _hook_run(hook, (), color=False)
-    assert (ret, _norm_out(out)) == (0, b'hello hello world\n')
-
-
-def test_local_dart_additional_dependencies_versioned(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'local-dart',
-            'name': 'local-dart',
-            'entry': 'secure-random -l 4 -b 16',
-            'language': 'dart',
-            'additional_dependencies': ['encrypt:5.0.0'],
-        }],
-    }
-    hook = _get_hook(config, store, 'local-dart')
-    ret, out = _hook_run(hook, (), color=False)
-    assert ret == 0
-    re_assert.Matches('^[a-f0-9]{8}\r?\n$').assert_matches(out.decode())
-
-
 def test_non_installable_hook_error_for_language_version(store, caplog):
     config = {
         'repo': 'local',
@@ -1145,29 +841,3 @@ def test_non_installable_hook_error_for_additional_dependencies(store, caplog):
         'using language `system` which does not install an environment.  '
         'Perhaps you meant to use a specific language?'
     )
-
-
-@skipif_cant_run_lua  # pragma: win32 no cover
-def test_lua_hook(tempdir_factory, store):
-    _test_hook_repo(
-        tempdir_factory, store, 'lua_repo',
-        'hello-world-lua', [], b'hello world\n',
-    )
-
-
-@skipif_cant_run_lua  # pragma: win32 no cover
-def test_local_lua_additional_dependencies(store):
-    config = {
-        'repo': 'local',
-        'hooks': [{
-            'id': 'local-lua',
-            'name': 'local-lua',
-            'entry': 'luacheck --version',
-            'language': 'lua',
-            'additional_dependencies': ['luacheck'],
-        }],
-    }
-    hook = _get_hook(config, store, 'local-lua')
-    ret, out = _hook_run(hook, (), color=False)
-    assert b'Luacheck' in out
-    assert ret == 0
